@@ -99,7 +99,7 @@ im2 = apply(im, 3, as.vector)                                # vectorize RGB
 
 km_rc = KMeans_rcpp(im2, clusters = 5, num_init = 5, max_iters = 100, 
                     
-                    initializer = 'optimal_init', threads = 1, verbose = F)
+                    initializer = 'optimal_init', verbose = F)
 
 km_rc$between.SS_DIV_total.SS
 
@@ -144,7 +144,7 @@ start = Sys.time()
 
 km_init = KMeans_rcpp(im3, clusters = 5, num_init = 5, max_iters = 100, 
                     
-                    initializer = 'kmeans++', threads = 1, verbose = F)
+                    initializer = 'kmeans++', verbose = F)
 
 end = Sys.time()
 
